@@ -653,7 +653,11 @@ class DataFile(object):
                 warnings.warn('Instrument of type "{}" is not supported yet....'.format(self.type))
                 #raise NotImplementedError('Instrument of type "{}" is not supported yet....'.format(self.type))
 
+        # Create Dasel
 
+        self.analyzerSelection = 0
+        self.detectorSelection = 0
+        self.comment = ''
         ### Weird additional changes:
 
         if self.type == 'MultiFLEXX':
@@ -676,7 +680,7 @@ class DataFile(object):
             if binning is None:
                 binning = self.binning
         elif self.type in ['MultiFLEXX','FlatCone']:
-            EPrDetector = self.binning
+            EPrDetector = 1
             if binning is None:
                 binning = self.binning
         else:
@@ -1808,6 +1812,8 @@ def test_DataFile_equility():
 
 def test_DataFile_plotA4():
     plt.ioff()
+    import matplotlib
+    matplotlib.use('Agg')
     fileName = 'Data/camea2018n000136.hdf'
     fileName2= 'Data/camea2018n000136.nxs'
     file = DataFile(fileName)
@@ -1835,6 +1841,8 @@ def test_DataFile_plotA4():
     
 def test_DataFile_plotEf():
     plt.ioff()
+    import matplotlib
+    matplotlib.use('Agg')
     fileName = 'Data/camea2018n000136.hdf'
     fileName2= 'Data/camea2018n000136.nxs'
     assertFile(fileName2)
@@ -1861,6 +1869,8 @@ def test_DataFile_plotEf():
 
 def test_DataFile_plotEfOverview():
     plt.ioff()
+    import matplotlib
+    matplotlib.use('Agg')
     fileName = 'Data/camea2018n000136.hdf'
     fileName2= 'Data/camea2018n000136.nxs'
     assertFile(fileName2)
@@ -1888,6 +1898,8 @@ def test_DataFile_plotEfOverview():
 
 def test_DataFile_plotNormalization():
     plt.ioff()
+    import matplotlib
+    matplotlib.use('Agg')
     fileName = 'Data/camea2018n000136.hdf'
     fileName2= 'Data/camea2018n000136.nxs'
     file = DataFile(fileName)
